@@ -22,12 +22,11 @@ class Command(NoArgsCommand):
 
         output = ""
         call_command("collectstatic", link=link, interactive=False, **options)
-        output += local("sudo chown -RL :www-data media/", capture=True)
-        output += local("sudo chown root:root cronjobs && sudo chmod a=r,u=rw "
-                        "cronjobs; exit 0", capture=True)
         output += local("sudo chmod -R a=rX {0}".format(settings.STATIC_ROOT),
                         capture=True)
-        output += local("sudo chmod -R g=rwX media/", capture=True)
-        output += local("sudo chmod -R g+rX ./", capture=True)
+        output += local("sudo chown -RL :www-data {0}".format(
+            settings.MEDIA_ROOT), capture=True)
+        output += local("sudo chmod -R g=rwX {0}".format(settings.MEDIA_ROOT),
+                        capture=True)
 
         self.stderr.write(output)
